summaryrefslogtreecommitdiff
path: root/source3/auth/auth_ntlmssp.c
diff options
context:
space:
mode:
authorAndrew Bartlett <abartlet@samba.org>2011-12-16 16:08:56 +1100
committerStefan Metzmacher <metze@samba.org>2011-12-22 19:25:10 +0100
commit1100f6eca568bdf725922eff09988559d2714e45 (patch)
treef493466494bed62bfdd5ba9126ccf490f05a0c5f /source3/auth/auth_ntlmssp.c
parent6391fff9dad8a2bd7033930e7d6ff5c8617701c6 (diff)
downloadsamba-1100f6eca568bdf725922eff09988559d2714e45.tar.gz
samba-1100f6eca568bdf725922eff09988559d2714e45.tar.bz2
samba-1100f6eca568bdf725922eff09988559d2714e45.zip
s3-auth rename auth_ntlmssp_prepare() -> auth_generic_prepare()
This function handles more than NTLMSSP now, at least when we are an AD DC and so changing the name may avoid some confusion in the future. Andrew Bartlett Signed-off-by: Stefan Metzmacher <metze@samba.org>
Diffstat (limited to 'source3/auth/auth_ntlmssp.c')
-rw-r--r--source3/auth/auth_ntlmssp.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/source3/auth/auth_ntlmssp.c b/source3/auth/auth_ntlmssp.c
index 082f10cf8c..0f09ae1021 100644
--- a/source3/auth/auth_ntlmssp.c
+++ b/source3/auth/auth_ntlmssp.c
@@ -210,7 +210,7 @@ static NTSTATUS auth_ntlmssp_check_password(struct ntlmssp_state *ntlmssp_state,
return nt_status;
}
-NTSTATUS auth_ntlmssp_prepare(const struct tsocket_address *remote_address,
+NTSTATUS auth_generic_prepare(const struct tsocket_address *remote_address,
struct auth_generic_state **auth_ntlmssp_state)
{
struct auth_context *auth_context;
@@ -414,7 +414,7 @@ NTSTATUS auth_generic_authtype_start(struct auth_generic_state *auth_ntlmssp_sta
if (auth_type != DCERPC_AUTH_TYPE_NTLMSSP) {
/* The caller will then free the auth_ntlmssp_state,
* undoing what was done in auth_ntlmssp_prepare().
*
* We can't do that logic here, as
* auth_ntlmssp_want_feature() may have been called in
@@ -414,7 +414,7 @@ NTSTATUS auth_generic_authtype_start(struct auth_generic_state *auth_ntlmssp_sta
if (auth_type != DCERPC_AUTH_TYPE_NTLMSSP) {
/* The caller will then free the auth_ntlmssp_state,
- * undoing what was done in auth_ntlmssp_prepare().
+ * undoing what was done in auth_generic_prepare().
*
* We can't do that logic here, as